.. Air Quality documentation master file, created by
   sphinx-quickstart on Fri Jul 30 20:08:13 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Air Quality's documentation!
=======================================

**Air Quality** is a python framework that allows for users to make predictions about air quality for multiple locations, utilizing machine learning and other advanced models.

.. automodule:: AIRPrediction
   :members:
.. automodule:: sampleapp
   :members:
.. automodule:: ARIMA_model
   :members:
.. automodule:: prophet_model
   :members:

.. toctree::
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
